pub struct ConnectionManager { /* private fields */ }Expand description
Connection manager for ClickHouse clients that implements BB8’s ManageConnection trait.
This manager handles creation, validation, and recycling of ClickHouse client connections.
It uses a ConnectionBuilder to configure new clients and periodically executes select 1;
to verify that clients are still valid.
Implementations
Sourceimpl ConnectionManager
impl ConnectionManager
Sourcepub fn new(builder: ConnectionBuilder) -> Self
pub fn new(builder: ConnectionBuilder) -> Self
Creates a new ConnectionManager with the provided builder.